pub enum EquivalenceType {
Type0,
Type1,
Type2,
Type3,
}Expand description
The “equivalence type” of the Unicode codepoint to the bytestring in the Encoding. The
equivalence types are defined by the Unicode consortium as such:
# The 1st column is the Unicode scalar value.
# The 2nd column is the codepage byte sequence.
# The 3rd column is the fallback indicator.
# The fallback indicator can have one of the following values:
# |0 for exact 1-1 roundtrip mapping
# |1 for the best fallback codepage byte sequence.
# |2 for the substitution character
# |3 for the best reverse fallback Unicode scaler valueVariants