Module parser

Module parser 

A .ucm file format (UniCode Mapping) Pest parser

Structs

UcmParser
This pest parser implements the grammar in ../resources/ucm.pest.

Enums

Rule

Traits

Parser
A trait with a single method that parses strings.

Functions

parse
Parse a UCM document into an Encoding.
parse_debug_dump
Dumps a tree to stderr of the .ucm data in the argument as seen by the Pest parser. The tree comes from the pest_ascii_tree crate.