Encoding

Struct Encoding 

pub struct Encoding {
    pub metadata: HashMap<String, String>,
    pub codepoints: Vec<Codepoint>,
    pub states: Vec<String>,
}
This represents a single .ucm (UniCode Mapping) file.

Fields

metadata: HashMap<String, String>

Note: does not include <icu:state>. Unordered.

codepoints: Vec<Codepoint>

This list is guaranteed to be in the order it is in the file.

states: Vec<String>

Parsing of states is left to those who wish to implement them. We provide a more complete parser of them by using UcmParser with Rule::state_row, but matching the rules is up to you. For more information on their format, see this page from the ICU User Guide.