A .ucm file format (UniCode Mapping) Pest parser
Structs
Enums
Traits
- Parser
- A trait with a single method that parses strings.
Functions
- parse
- Parse a UCM document into an
Encoding. - parse_
debug_ dump - Dumps a tree to
stderrof the.ucmdata in the argument as seen by the Pest parser. The tree comes from thepest_ascii_treecrate.